@@ -1,15 +1,21 @@
 #!/bin/bash
 
+# Detect OS
+OS="$(uname -s)"
+
+# Map to FVM naming
+case "$OS" in
+Linux*) OS='linux' ;;
+Darwin*) OS='macos' ;;
+*)
+    echo "Unsupported OS" >&2
+    exit 1
+    ;;
+esac
+
 # Define the FVM directory and binary path
 FVM_DIR="$HOME/.fvm_flutter"
-BIN_LINK="/usr/local/bin/fvm"
-
-# Check if FVM is installed
-if ! command -v fvm &> /dev/null
-then
-    echo "FVM is not installed. Exiting."
-    exit 1
-fi
+FVM_DIR_BIN="$FVM_DIR/bin"
 
 # Remove the FVM binary
 echo "Uninstalling FVM..."
@@ -18,15 +24,10 @@ rm -rf "$FVM_DIR" || {
     exit 1
 }
 
-# Remove the symlink
-rm -f "$BIN_LINK" || {
-    echo "Failed to remove FVM symlink: $BIN_LINK."
-    exit 1
-}
+echo "You can remove \"export PATH=$FVM_DIR_BIN:\$PATH\" from your ~/.bashrc, ~/.zshrc (or similar)"
 
 # Check if uninstallation was successful
-if command -v fvm &> /dev/null
-then
+if command -v fvm &>/dev/null; then
     echo "Uninstallation failed. Please try again later."
     exit 1
 fi
