@@ -1,7 +1,9 @@
 import 'dart:io';
 
 import 'package:io/io.dart';
+import 'package:meta/meta.dart';
 import 'package:path/path.dart' as path;
+import 'package:pub_semver/pub_semver.dart';
 
 import '../models/cache_flutter_version_model.dart';
 import '../models/flutter_version_model.dart';
@@ -23,6 +25,14 @@ enum CacheIntegrity {
 class CacheService extends ContextualService {
   const CacheService(super.context);
 
+  static String _normalizeVersion(String value) {
+    if (value.startsWith('v') || value.startsWith('V')) {
+      return value.substring(1);
+    }
+
+    return value;
+  }
+
   /// Verifies that cache is correct
   /// returns 'true' if cache is correct 'false' if its not
   Future<bool> _verifyIsExecutable(CacheFlutterVersion version) async {
@@ -36,9 +46,10 @@ class CacheService extends ContextualService {
     // If its a channel return true
     if (version.isChannel) return true;
     // If sdkVersion is not available return true
-    if (version.flutterSdkVersion == null) return true;
+    final cached = version.flutterSdkVersion;
+    if (cached == null) return true;
 
-    return version.flutterSdkVersion == version.version;
+    return versionsMatch(version.version, cached);
   }
 
   Link get _globalCacheLink => Link(context.globalCacheLink);
@@ -144,7 +155,7 @@ class CacheService extends ContextualService {
       return Directory(
         path.join(context.versionsCachePath, version.fork!, version.version),
       );
-    } // Standard path (unchanged): versionsCachePath/versionName
+    } // Standard path: versionsCachePath/version.name
 
     return Directory(path.join(context.versionsCachePath, version.name));
   }
@@ -245,4 +256,60 @@ class CacheService extends ContextualService {
       versionDir.renameSync(newDir.path);
     }
   }
+
+  /// Determines if [configured] and [cached] versions should be considered
+  /// matching.
+  ///
+  /// Matching rules:
+  /// 1. Exact string match (after normalizing leading 'v'/'V' prefix)
+  /// 2. If either has build metadata (+xxx), both must match exactly
+  /// 3. If both have pre-release identifiers (-xxx), both must match exactly
+  /// 4. If [configured] has pre-release but [cached] does not, match on
+  ///    `major.minor.patch` (allows dev builds to match stable SDKs)
+  /// 5. If [cached] has pre-release but [configured] does not, require exact match
+  /// 6. For non-semver versions (e.g., git refs), catches [FormatException] and
+  ///    falls back to normalized string equality with a warning logged
+  ///
+  /// This handles Flutter SDK naming where the cached SDK may strip pre-release
+  /// suffixes from the configured version.
+  @visibleForTesting
+  bool versionsMatch(String configured, String cached) {
+    if (configured == cached) return true;
+
+    final normConfigured = _normalizeVersion(configured);
+    final normCached = _normalizeVersion(cached);
+
+    if (normConfigured == normCached) return true;
+
+    try {
+      final configVer = Version.parse(normConfigured);
+      final cachedVer = Version.parse(normCached);
+
+      if (configVer.build.isNotEmpty || cachedVer.build.isNotEmpty) {
+        return configVer == cachedVer;
+      }
+
+      if (configVer.preRelease.isNotEmpty && cachedVer.preRelease.isNotEmpty) {
+        return configVer == cachedVer;
+      }
+
+      if (configVer.preRelease.isNotEmpty && cachedVer.preRelease.isEmpty) {
+        return configVer.major == cachedVer.major &&
+            configVer.minor == cachedVer.minor &&
+            configVer.patch == cachedVer.patch;
+      }
+
+      // Remaining case: configured has no pre-release but cached does;
+      // require exact match (which will fail because of differing pre-release).
+      return configVer == cachedVer;
+    } on FormatException catch (e) {
+      logger.warn(
+        'Unable to parse versions as semantic versions: '
+        'configured="$configured", cached="$cached". '
+        'Falling back to string comparison. Error: $e',
+      );
+
+      return normConfigured == normCached;
+    }
+  }
 }
