@@ -1,5 +1,7 @@
 import 'dart:io';
 
+import 'package:io/io.dart';
+
 /// Represents an FVM-specific exception that carries a user-facing message.
 ///
 /// Exceptions of this type are intended to be self-explanatory, no debugging info
@@ -27,3 +29,18 @@ class AppDetailedException extends AppException {
 bool checkIfNeedsPrivilegePermission(FileSystemException err) {
   return err.osError?.errorCode == 1314 && Platform.isWindows;
 }
+
+class ForceExit extends AppException {
+  final int exitCode;
+
+  const ForceExit(super.message, this.exitCode);
+
+  static ForceExit success([String? message]) =>
+      ForceExit(message ?? '', ExitCode.success.code);
+
+  static ForceExit unavailable([String? message]) =>
+      ForceExit(message ?? '', ExitCode.unavailable.code);
+
+  @override
+  String toString() => message;
+}
